@@ -73,14 +73,22 @@ def num2deg(xtile, ytile, zoom):
     return (lon_deg, lat_deg)
 
 ##########################################################
-def dist_to_deltalon(dist, lonref, latref):
-    """Get the variation in longitude based on a reference lat and lon.
+def dist_to_deltalonlat(dist, lonref, latref):
+    """Get the deltalon and deltalat based on a reference lat and lon.
     For the same distance, lon varies more than lat."""
     def get_delta_lon_from_d(lon1, lat1=latref, lon2=lonref, lat2=latref):
-        return dist - haversine(lon1, lat1, lon2, lat2)
+        return dist - haversine([lon1, lat1], [lon2, lat2])
+
+    def get_delta_lat_from_d(lat1, lon1=lonref, lat2=latref, lon2=lonref):
+        return dist - haversine([lon1, lat1], [lon2, lat2])
 
     lon2 = lonref + 20 # a large enough diff in lon to contain the @dist
     lon2 = scipy.optimize.bisect(get_delta_lon_from_d, lonref, lon2,
             xtol=0.00001, rtol=0.00001)
-    return np.abs(lon2 - lonref)
+
+    lat2 = latref + 20 # a large enough diff in lon to contain the @dist
+    lat2 = scipy.optimize.bisect(get_delta_lat_from_d, latref, lat2,
+            xtol=0.00001, rtol=0.00001)
+
+    return np.abs(lon2 - lonref), np.abs(lat2 - latref)
 
