@@ -56,5 +56,5 @@ def plot_graph(gin, plotpath, shppath=''):
         ecoords.append([ [float(g.vs[e.source]['x']), float(g.vs[e.source]['y'])],
                 [float(g.vs[e.target]['x']), float(g.vs[e.target]['y'])], ])
 
-    import plot
-    plot.plot_graph(vcoords, ecoords, plotpath, shppath)
+    import myutils.plot
+    myutils.plot.plot_graph(vcoords, ecoords, plotpath, shppath)
