@@ -1,4 +1,5 @@
 import matplotlib.pyplot as plt
+import matplotlib.collections as mc
 import numpy as np
 
 palettes = {
@@ -63,14 +64,13 @@ def create_meshgrid(x, y, nx=100, ny=100, relmargin=.1):
 #############################################################
 def plot_graph(vcoords, ecoords, plotpath, shppath=''):
     """Plot the grpah, with vertices colored by accessibility."""
-    info(inspect.stack()[0][3] + '()')
 
     fig, ax = plt.subplots(figsize=(7, 7))
 
     sc = ax.scatter(vcoords[:, 0], vcoords[:, 1], c='k',
             linewidths=0, alpha=.8, s=3, zorder=10) # vertices
 
-    segs = LineCollection(ecoords, colors='k', linewidths=.5, alpha=.5) # edges
+    segs = mc.LineCollection(ecoords, colors='k', linewidths=.5, alpha=.5) # edges
     ax.add_collection(segs)
 
     if shppath: # border
